@@ -33,9 +33,10 @@
 #  define PIMCOMMON_DEPRECATED_NO_EXPORT PIMCOMMON_NO_EXPORT PIMCOMMON_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define PIMCOMMON_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef PIMCOMMON_NO_DEPRECATED
+#    define PIMCOMMON_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
